<h1 align="center">Sylius Ecotax Plugin</h1>

# Installation

```bash
composer require dedi/sylius-ecotax-plugin
```

Add plugin class to your `config/bundles.php`:

```php
<?php
$bundles = [
    // ...
    Dedi\SyliusEcotaxPlugin\DediSyliusEcotaxPlugin::class => ['all' => true],    
    // ...
];
```

## Import the plugin configuration

```yaml
# config/packages/dedi_sylius_ecotax_plugin.yaml
imports:
    - { resource: "@DediSyliusEcotaxPlugin/config/config.yaml" }
```

## Import the routing configuration

```yaml
# config/routes/dedi_sylius_ecotax_plugin.yaml
dedi_sylius_ecotax_plugin_admin:
    resource: "@DediSyliusEcotaxPlugin/config/admin_routing.yml"
    prefix: "/admin"
```


## Use ChannelPricing trait and implement interfaces

```php
<?php

namespace App\Entity;

use Dedi\SyliusEcotaxPlugin\Model\EcotaxesAwareInterface;
use Dedi\SyliusEcotaxPlugin\Model\EcotaxesAwareTrait;
use Doctrine\ORM\Mapping as ORM;
use Sylius\Component\Core\Model\ChannelPricing as BaseChannelPricing;

/**
 * @ORM\Entity()
 * @ORM\Table(name="sylius_channel_pricing")
 */
class ChannelPricing extends BaseChannelPricing implements EcotaxesAwareInterface
{
    use EcotaxesAwareTrait {
        __construct as private initializeEcotaxesCollection;
    }

    public function __construct()
    {
        parent::__construct();
        $this->initializeEcotaxesCollection();
    }
}
```

```php
<?php

namespace App\Entity;

use Dedi\SyliusEcotaxPlugin\Model\EcotaxAdjustmentsAwareInterface;
use Dedi\SyliusEcotaxPlugin\Model\EcotaxAdjustmentsAwareTrait;
use Doctrine\ORM\Mapping as ORM;
use Sylius\Component\Core\Model\Order as BaseOrder;

/**
 * @ORM\Entity()
 * @ORM\Table(name="sylius_order")
 */
class Order extends BaseOrder implements EcotaxAdjustmentsAwareInterface
{
    use EcotaxAdjustmentsAwareTrait;
}
```

```php
<?php

namespace App\Entity;

use Dedi\SyliusEcotaxPlugin\Model\EcotaxAdjustmentsAwareInterface;
use Dedi\SyliusEcotaxPlugin\Model\EcotaxAdjustmentsAwareTrait;
use Doctrine\ORM\Mapping as ORM;
use Sylius\Component\Core\Model\OrderItem as BaseOrderItem;

/**
 * @ORM\Entity()
 * @ORM\Table(name="sylius_order_item")
 */
class OrderItem extends BaseOrderItem implements EcotaxAdjustmentsAwareInterface
{
    use EcotaxAdjustmentsAwareTrait;
}
```

## Override sylius resources

```yaml
sylius_order:
    resources:
        order:
            classes:
                model: App\Entity\Order
        order_item:
            classes:
                model: App\Entity\OrderItem
sylius_core:
    resources:
        channel_pricing:
            classes:
                model: App\Entity\ChannelPricing
```

## Copy templates

Overwrite following templates in your project with templates under `/tests/Application/templates/bundles`

- @SyliusShopBundle/Cart/
- @SyliusShopBundle/Checkout/
- @SyliusShopBundle/Common/
- @SyliusShopBundle/Product/
- @SyliusAdminBundle/Order/
- @SyliusAdminBundle/ProductVariant/

## Run migrations

```
bin/console doctrine:migration:diff
bin/console doctrine:migration:migrate
````
