<?php

declare(strict_types=1);

namespace Dedi\SyliusEcotaxPlugin\Form\Extension;

use Dedi\Contracts\SyliusPluginSettings\SettingsProviderInterface;
use Dedi\SyliusEcotaxPlugin\Form\Type\EcotaxType;
use Sylius\Bundle\CoreBundle\Form\Type\Product\ChannelPricingType;
use Symfony\Component\Form\AbstractTypeExtension;
use Symfony\Component\Form\Extension\Core\Type\CollectionType;
use Symfony\Component\Form\FormBuilderInterface;

class ChannelPricingTypeExtension extends AbstractTypeExtension
{
    public function __construct(private SettingsProviderInterface $settingsProvider)
    {
    }

    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        $settings = $this->settingsProvider->provide();

        if ($settings->isEnabled()) {
            $builder
                ->add('ecotaxes', CollectionType::class, [
                    'entry_type' => EcotaxType::class,
                    'entry_options' => [
                        'label' => 'dedi_ecotax.ui.ecotax',
                    ],
                    'allow_add' => true,
                    'allow_delete' => true,
                    'by_reference' => false,
                ]);
        }
    }

    public static function getExtendedTypes(): iterable
    {
        return [ChannelPricingType::class];
    }
}
